// This file is part of Substrate.

// Copyright (C) 2021 Parity Technologies (UK) Ltd.
// SPDX-License-Identifier: Apache-2.0

// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

//! Autogenerated weights for pallet_storage
//!
//! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
//! DATE: 2021-09-15, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
//! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("dev"), DB CACHE: 128

// Executed Command:
// ./target/release/deer-node
// benchmark
// --chain=dev
// --steps=50
// --repeat=20
// --pallet=pallet-storage
// --extrinsic=*
// --execution=wasm
// --wasm-execution=compiled
// --heap-pages=4096
// --output=./pallets/storage/src/weights.rs
// --template=./scripts/frame-weight-template.hbs


#![cfg_attr(rustfmt, rustfmt_skip)]
#![allow(unused_parens)]
#![allow(unused_imports)]

use frame_support::{
	traits::Get,
	weights::{constants::RocksDbWeight, Weight},
};
use sp_std::marker::PhantomData;

/// Weight functions needed for pallet_storage.
pub trait WeightInfo {
	fn set_enclave() -> Weight;
	fn stash() -> Weight;
	fn withdraw() -> Weight;
	fn register() -> Weight;
	fn report(x: u32, y: u32, ) -> Weight;
	fn store() -> Weight;
	fn force_delete() -> Weight;
}

/// Weights for pallet_storage using the Substrate node and recommended hardware.
pub struct SubstrateWeight<T>(PhantomData<T>);
impl<T: frame_system::Config> WeightInfo for SubstrateWeight<T> {
	// Storage: FileStorage Enclaves (r:1 w:1)
	fn set_enclave() -> Weight {
		(20_631_000 as Weight)
			.saturating_add(T::DbWeight::get().reads(1 as Weight))
			.saturating_add(T::DbWeight::get().writes(1 as Weight))
	}
	// Storage: FileStorage Stashs (r:1 w:1)
	fn stash() -> Weight {
		(52_360_000 as Weight)
			.saturating_add(T::DbWeight::get().reads(1 as Weight))
			.saturating_add(T::DbWeight::get().writes(1 as Weight))
	}
	// Storage: FileStorage Stashs (r:1 w:1)
	fn withdraw() -> Weight {
		(53_684_000 as Weight)
			.saturating_add(T::DbWeight::get().reads(1 as Weight))
			.saturating_add(T::DbWeight::get().writes(1 as Weight))
	}
	// Storage: FileStorage Registers (r:1 w:1)
	// Storage: FileStorage Stashs (r:1 w:1)
	// Storage: Timestamp Now (r:1 w:0)
	// Storage: FileStorage Enclaves (r:2 w:0)
	fn register() -> Weight {
		(4_199_317_000 as Weight)
			.saturating_add(T::DbWeight::get().reads(5 as Weight))
			.saturating_add(T::DbWeight::get().writes(2 as Weight))
	}
	// Storage: FileStorage Stashs (r:1 w:1)
	// Storage: FileStorage Registers (r:1 w:0)
	// Storage: FileStorage Enclaves (r:1 w:0)
	// Storage: FileStorage CurrentRound (r:1 w:0)
	// Storage: FileStorage Nodes (r:1 w:1)
	// Storage: FileStorage RoundsReward (r:1 w:1)
	// Storage: FileStorage StoragePotReserved (r:1 w:1)
	// Storage: FileStorage FileOrders (r:30 w:0)
	// Storage: FileStorage RoundsReport (r:1 w:1)
	// Storage: FileStorage RoundsSummary (r:1 w:1)
	// Storage: FileStorage StoreFiles (r:1 w:1)
	fn report(x: u32, y: u32, ) -> Weight {
		(2_764_924_000 as Weight)
			// Standard Error: 67_000
			.saturating_add((15_524_000 as Weight).saturating_mul(x as Weight))
			// Standard Error: 67_000
			.saturating_add((9_758_000 as Weight).saturating_mul(y as Weight))
			.saturating_add(T::DbWeight::get().reads(10 as Weight))
			.saturating_add(T::DbWeight::get().reads((1 as Weight).saturating_mul(x as Weight)))
			.saturating_add(T::DbWeight::get().reads((1 as Weight).saturating_mul(y as Weight)))
			.saturating_add(T::DbWeight::get().writes(7 as Weight))
			.saturating_add(T::DbWeight::get().writes((1 as Weight).saturating_mul(x as Weight)))
	}
	// Storage: FileStorage StoreFiles (r:1 w:1)
	fn store() -> Weight {
		(55_171_000 as Weight)
			.saturating_add(T::DbWeight::get().reads(1 as Weight))
			.saturating_add(T::DbWeight::get().writes(1 as Weight))
	}
	// Storage: FileStorage StoreFiles (r:1 w:1)
	// Storage: FileStorage FileOrders (r:1 w:0)
	// Storage: FileStorage StoragePotReserved (r:1 w:1)
	fn force_delete() -> Weight {
		(33_135_000 as Weight)
			.saturating_add(T::DbWeight::get().reads(3 as Weight))
			.saturating_add(T::DbWeight::get().writes(2 as Weight))
	}
}

// For backwards compatibility and tests
impl WeightInfo for () {
	// Storage: FileStorage Enclaves (r:1 w:1)
	fn set_enclave() -> Weight {
		(20_631_000 as Weight)
			.saturating_add(RocksDbWeight::get().reads(1 as Weight))
			.saturating_add(RocksDbWeight::get().writes(1 as Weight))
	}
	// Storage: FileStorage Stashs (r:1 w:1)
	fn stash() -> Weight {
		(52_360_000 as Weight)
			.saturating_add(RocksDbWeight::get().reads(1 as Weight))
			.saturating_add(RocksDbWeight::get().writes(1 as Weight))
	}
	// Storage: FileStorage Stashs (r:1 w:1)
	fn withdraw() -> Weight {
		(53_684_000 as Weight)
			.saturating_add(RocksDbWeight::get().reads(1 as Weight))
			.saturating_add(RocksDbWeight::get().writes(1 as Weight))
	}
	// Storage: FileStorage Registers (r:1 w:1)
	// Storage: FileStorage Stashs (r:1 w:1)
	// Storage: Timestamp Now (r:1 w:0)
	// Storage: FileStorage Enclaves (r:2 w:0)
	fn register() -> Weight {
		(4_199_317_000 as Weight)
			.saturating_add(RocksDbWeight::get().reads(5 as Weight))
			.saturating_add(RocksDbWeight::get().writes(2 as Weight))
	}
	// Storage: FileStorage Stashs (r:1 w:1)
	// Storage: FileStorage Registers (r:1 w:0)
	// Storage: FileStorage Enclaves (r:1 w:0)
	// Storage: FileStorage CurrentRound (r:1 w:0)
	// Storage: FileStorage Nodes (r:1 w:1)
	// Storage: FileStorage RoundsReward (r:1 w:1)
	// Storage: FileStorage StoragePotReserved (r:1 w:1)
	// Storage: FileStorage FileOrders (r:30 w:0)
	// Storage: FileStorage RoundsReport (r:1 w:1)
	// Storage: FileStorage RoundsSummary (r:1 w:1)
	// Storage: FileStorage StoreFiles (r:1 w:1)
	fn report(x: u32, y: u32, ) -> Weight {
		(2_764_924_000 as Weight)
			// Standard Error: 67_000
			.saturating_add((15_524_000 as Weight).saturating_mul(x as Weight))
			// Standard Error: 67_000
			.saturating_add((9_758_000 as Weight).saturating_mul(y as Weight))
			.saturating_add(RocksDbWeight::get().reads(10 as Weight))
			.saturating_add(RocksDbWeight::get().reads((1 as Weight).saturating_mul(x as Weight)))
			.saturating_add(RocksDbWeight::get().reads((1 as Weight).saturating_mul(y as Weight)))
			.saturating_add(RocksDbWeight::get().writes(7 as Weight))
			.saturating_add(RocksDbWeight::get().writes((1 as Weight).saturating_mul(x as Weight)))
	}
	// Storage: FileStorage StoreFiles (r:1 w:1)
	fn store() -> Weight {
		(55_171_000 as Weight)
			.saturating_add(RocksDbWeight::get().reads(1 as Weight))
			.saturating_add(RocksDbWeight::get().writes(1 as Weight))
	}
	// Storage: FileStorage StoreFiles (r:1 w:1)
	// Storage: FileStorage FileOrders (r:1 w:0)
	// Storage: FileStorage StoragePotReserved (r:1 w:1)
	fn force_delete() -> Weight {
		(33_135_000 as Weight)
			.saturating_add(RocksDbWeight::get().reads(3 as Weight))
			.saturating_add(RocksDbWeight::get().writes(2 as Weight))
	}
}
